@@ -158,6 +158,9 @@ def govuk_input(
     params = _params(question, data, errors, **kwargs)
 
     if question.type in ("number", "pricing"):
+        # If value is 0, it can get evaluated as False, so we should stringify it
+        if isinstance(params.get("value"), int):
+            params["value"] = str(params["value"])
         params["classes"] += " govuk-input--width-5"
         params["spellcheck"] = False
         if question.get("limits") and question.limits.get("integer_only") is True:
@@ -526,7 +529,7 @@ def _params(
             hint["classes"] = " ".join(kwargs["hint_classes"])
         params["hint"] = hint
 
-    if data and data.get(input_id):
+    if data and data.get(input_id) is not None:
         params["value"] = data[input_id]
 
     if errors and errors.get(input_id):
@@ -608,20 +611,20 @@ def render(ctx, obj: Renderable, *, question=None) -> Markup:
 
                 visit(params)
 
-                inner_html += Markup(macro(params))
+                inner_html += Markup(macro(params))  # type:ignore # fix once drop support for Flask 1.0
             else:
-                inner_html += Markup(macro())
+                inner_html += Markup(macro())  # type:ignore # fix once drop support for Flask 1.0
 
             if "fieldset" in obj:
                 inner_html = Markup(
                     ctx.resolve("govukFieldset")(obj["fieldset"], caller=lambda: inner_html)
                 )
 
-            html += inner_html
+            html += inner_html  # type:ignore # fix once drop support for Flask 1.0
 
         return html
     elif isinstance(obj, (str, Markup)):
-        return escape(obj)
+        return escape(obj)  # type:ignore # fix once drop support for Flask 1.0
     else:
         raise TypeError("render() expects a dict or string type, or a list of dicts or string types")
 
